@@ -1,11 +1,10 @@
 from mediator.common.handler.base import Handler, HandlerInfo
-from mediator.common.handler.handlers import DirectHandler, MappedDirectHandler
+from mediator.common.handler.handlers import CallableHandler
 
 __all__ = [
     # base
     "Handler",
     "HandlerInfo",
     # handlers
-    "DirectHandler",
-    "MappedDirectHandler",
+    "CallableHandler",
 ]
